@@ -20,8 +20,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef JOURNALD_ANALYZER_H
-#define JOURNALD_ANALYZER_H
+#pragma once
 
 #include "analyzer.h"
 #include "logFile.h"
@@ -53,4 +52,3 @@ protected:
     int updateModel(QList<JournalEntry> &entries, ReadingMode readingMode);
 };
 
-#endif // _JOURNALD_ANALYZER_H
