@@ -28,12 +28,13 @@
 #include "logging.h"
 
 #include "sambaAnalyzer.h"
-#include "sambaItemBuilder.h"
-#include "sambaConfigurationWidget.h"
 #include "sambaConfiguration.h"
+#include "sambaConfigurationWidget.h"
+#include "sambaItemBuilder.h"
 
 SambaLogMode::SambaLogMode(QSharedPointer<SambaConfiguration> &sambaConfiguration,
-                           SambaConfigurationWidget *sambaConfigurationWidget, SambaItemBuilder *itemBuilder)
+                           SambaConfigurationWidget *sambaConfigurationWidget,
+                           SambaItemBuilder *itemBuilder)
     : LogMode(QStringLiteral(SAMBA_LOG_MODE_ID), i18n("Samba Log"), QStringLiteral(SAMBA_MODE_ICON))
 {
     d->logModeConfiguration = sambaConfiguration;
@@ -43,9 +44,9 @@ SambaLogMode::SambaLogMode(QSharedPointer<SambaConfiguration> &sambaConfiguratio
     // Samba Log Action
     d->action = createDefaultAction();
     d->action->setToolTip(i18n("Display the Samba log."));
-    d->action->setWhatsThis(i18n(
-        "Displays the Samba log in the current tab. Samba is the file sharing server which interacts with "
-        "Microsoft Windows network."));
+    d->action->setWhatsThis(
+        i18n("Displays the Samba log in the current tab. Samba is the file sharing server which interacts with "
+             "Microsoft Windows network."));
 
     checkLogFilesPresence(sambaConfiguration->sambaPaths());
 }
@@ -60,8 +61,8 @@ Analyzer *SambaLogMode::createAnalyzer(const QVariant &options)
     return new SambaAnalyzer(this);
 }
 
-QList<LogFile> SambaLogMode::createLogFiles()
+QVector<LogFile> SambaLogMode::createLogFiles()
 {
-    SambaConfiguration *sambaConfiguration = logModeConfiguration<SambaConfiguration *>();
+    auto *sambaConfiguration = logModeConfiguration<SambaConfiguration *>();
     return sambaConfiguration->findNoModeLogFiles(sambaConfiguration->sambaPaths());
 }
