@@ -21,18 +21,15 @@
 
 #include "systemFactory.h"
 
-
 #include "logMode.h"
 #include "logging.h"
 
 #include "simpleAction.h"
 #include "systemLogMode.h"
 
-
 QList<LogMode *> SystemLogModeFactory::createLogModes() const
 {
-    QList<LogMode *> logModes;
-    logModes.append(new SystemLogMode());
+    const QList<LogMode *> logModes{new SystemLogMode()};
     return logModes;
 }
 
@@ -40,10 +37,11 @@ LogModeAction *SystemLogModeFactory::createLogModeAction() const
 {
     LogMode *logMode = Globals::instance().findLogMode(QStringLiteral(SYSTEM_LOG_MODE_ID));
 
-    if (!logMode->filesExist())
+    if (!logMode->filesExist()) {
         return nullptr;
+    }
 
-    SimpleAction *logModeAction = new SimpleAction(logMode->action(), logMode);
+    auto logModeAction = new SimpleAction(logMode->action(), logMode);
 
     return logModeAction;
 }
