@@ -19,8 +19,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef X_SESSION_ITEM_BUILDER_H
-#define X_SESSION_ITEM_BUILDER_H
+#pragma once
 
 #include <QString>
 
@@ -54,4 +53,3 @@ public:
     QString createFormattedText(LogLine *line) const override;
 };
 
-#endif // _X_SESSION_ITEM_BUILDER_H
